@@ -15,11 +15,23 @@
 """
 
 """
-from typing import Dict, Union, List, Any, NoReturn, Iterable
+from typing import Dict, Union, List, Any, NoReturn, Iterable, Tuple, Generator
 
 
-def flatten(data: Any, ignore_types: tuple = (str, bytes)):
-    if isinstance(data, Iterable):
+def flatten(data: Union[List[Any], Tuple[Any]], ignore_types: tuple = (str, bytes)) -> Generator:
+    """
+    flatten list or tuple
+    :param data: a list or a tuple
+    :param ignore_types: types will not be flatten
+    :return: a generator of a flatten list
+
+    >>> [x for x in flatten([[1,2,('abc',4)],'hello'])]
+    [1, 2, 'abc', 4, 'hello']
+    >>> [x for x in flatten('abc')]
+    ['abc']
+    """
+
+    if isinstance(data, Iterable) and not isinstance(data, ignore_types):
         for item in data:
             if isinstance(item, Iterable) and not isinstance(item, ignore_types):
                 yield from flatten(item)
@@ -29,7 +41,7 @@ def flatten(data: Any, ignore_types: tuple = (str, bytes)):
         yield data
 
 
-info = [[1,2,('sssssss',4)],5]
-
-for d in flatten(info):
-    print(d)
\ No newline at end of file
+if __name__ == '__main__':
+    # print([x for x in flatten('abc')])
+    import doctest
+    doctest.testmod()
